bayespy.inference.vmp.nodes.gaussian.GaussianARDDistribution.compute_mask_to_parent
===================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianARDDistribution.compute_mask_to_parent